.resource-example .v-toolbar{cursor:pointer}h1 a{display:inline-block}h1 a i.material-icons{vertical-align:middle;display:none}h1:hover a i.material-icons{display:inline-block;width:30px}.theme--light.v-table tbody tr:hover:not(.v-datatable__expand-row){background:initial}.home{margin-top:6px;margin-bottom:500px}.theme--dark a,.theme--dark h1,.theme--dark h2,.theme--dark h3,.theme--dark h4,.theme--dark h5,.theme--dark h6,.theme--dark p{color:#ccc}.theme--dark code{background-color:#181818;color:#c50054}.param-required{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;display:inline-block;vertical-align:middle;height:17px;padding:0 2px;color:red}pre{background:#f4f4f4;border:none;border-left:3px solid #f36d33;color:#333;page-break-inside:avoid;font-family:monospace;font-size:12px;line-height:1.6;margin-bottom:1.6em;max-width:100%;overflow:auto;padding:1em 1.5em;display:block;word-wrap:break-word;max-height:400px}pre code{background-color:initial;-webkit-box-shadow:initial;box-shadow:none;color:#333;font-weight:400;font-size:11px}.theme--dark pre,.theme--dark pre code{background-color:#666;color:#eee}.application--is-rtl code,.application--is-rtl pre{direction:ltr}